@@ -33,6 +33,9 @@ swipeRwrapper <- function(...) {
 #'   \code{"cube"}, \code{"coverflow"}, \code{"flip"}, or \code{"cards"}
 #' @param cubeEffect list of settings for the cube when \code{effect="cube"}
 #' @param initialSlide index of the first slide to be shown
+#' @param keyboard named list of settings for the keyboard navigation, or just
+#'   \code{TRUE} to enable the keyboard navigation with the default options,
+#'   or \code{FALSE} to disable the keyboard navigation
 #' @param zoom Boolean, whether to enable the zoom on slide's double tap;
 #'   all zoomable slides must be wrapped in a \code{div} with
 #'   \code{swiper-zoom-container} class
@@ -71,7 +74,7 @@ swipeRwrapper <- function(...) {
 #' )
 #'
 #' swipeR(
-#'   wrapper, height = "400px", width = "70%", thumbs = TRUE,
+#'   wrapper, height = "400px", width = "70%", thumbs = TRUE, keyboard = TRUE,
 #'   on = list(reachEnd = htmlwidgets::JS("function() {alert('the end');}"))
 #' )
 #'
@@ -338,8 +341,11 @@ swipeR <- function(
     wrapper, width = "100%", height = "100%",
     navigationColor = "white", paginationColor = "white", bulletsSize = "8px",
     id = NULL, direction = "horizontal", effect = "slide",
-    cubeEffect = list(shadow = TRUE, slidesShadow = TRUE, shadowOffset = 20, shadowScale = 0.94),
-    initialSlide = 1, zoom = FALSE, loop = FALSE, rewind = FALSE,
+    cubeEffect = list(shadow = TRUE, slidesShadow = TRUE, shadowOffset = 20,
+                      shadowScale = 0.94),
+    initialSlide = 1,
+    keyboard = list(enabled = FALSE, onlyInViewport = TRUE, pageUpDown = TRUE),
+    zoom = FALSE, loop = FALSE, rewind = FALSE,
     slidesPerView = 1, spaceBetween = 30, speed = 300,
     scrollbar = FALSE, autoplay = FALSE,
     thumbs = FALSE, thumbsPerView = 2, thumbsHeight = "60px",
@@ -350,6 +356,11 @@ swipeR <- function(
     wrapper, id, width, height, scrollbar,
     navigationColor, paginationColor, bulletsSize
   )
+  if(isTRUE(keyboard)) {
+    keyboard <- list(enabled = TRUE, onlyInViewport = TRUE, pageUpDown = TRUE)
+  } else if(isFALSE(keyboard)) {
+    keyboard <- list(enabled = FALSE, onlyInViewport = TRUE, pageUpDown = TRUE)
+  }
   x <- list(
     "html"                = tags[["html"]],
     "thumbs"              = if(thumbs) thumbsDiv(wrapper, width, thumbsHeight),
@@ -362,6 +373,7 @@ swipeR <- function(
       ),
     "cubeEffect"          = cubeEffect,
     "initialSlide"        = initialSlide - 1,
+    "keyboard"            = keyboard,
     "zoom"                = zoom,
     "loop"                = loop,
     "rewind"              = rewind && !loop,
